==> mcu_plus_sdk_am263x_08_06_00_34_docs_only.tar.xz: mcu_plus_sdk_am263x_08_06_00_34_docs_only/docs/api_guide_am263x/group__DRV__MCSPI__MODULE.js <==
var group__DRV__MCSPI__MODULE =
[
    [ "APIs for MCSPI DMA mode", "group__MCSPI__DMA.html", "group__MCSPI__DMA" ],
    [ "mcspi/v0/mcspi.h", "mcspi_2v0_2mcspi_8h.html", null ],
    [ "MCSPI_Transaction", "structMCSPI__Transaction.html", [
      [ "channel", "structMCSPI__Transaction.html#a69dc47581d6f116db83f816065866748", null ],
      [ "csDisable", "structMCSPI__Transaction.html#ad6b33cae4d549a0b1780b72cf75ea2b4", null ],
      [ "dataSize", "structMCSPI__Transaction.html#a145ceab9ccb5279a3b0994feb10a6444", null ],
      [ "count", "structMCSPI__Transaction.html#a03649a1e749d0661e4a78fbe615ce412", null ],
      [ "txBuf", "structMCSPI__Transaction.html#a1344bb4f68f64e6841a25884de818f7b", null ],
      [ "rxBuf", "structMCSPI__Transaction.html#a13379551362963f30946a9ef45d9efc9", null ],
      [ "args", "structMCSPI__Transaction.html#a7789f4810d4b1818b3cd2a1cdd4a01cd", null ],
      [ "status", "structMCSPI__Transaction.html#a5bd291f7ca72200e01074457999d9ef9", null ]
    ] ],
    [ "MCSPI_OpenParams", "structMCSPI__OpenParams.html", [
      [ "transferMode", "structMCSPI__OpenParams.html#a0b4ecaba7263bd18bc7e40924d8d6c97", null ],
      [ "transferTimeout", "structMCSPI__OpenParams.html#a1a61eb9a3dafb53eb367e31b41a7116b", null ],
      [ "transferCallbackFxn", "structMCSPI__OpenParams.html#a43a61b1bdcb52eebaf0d756f5e5500d8", null ],
      [ "msMode", "structMCSPI__OpenParams.html#ad539f2b8771de73167b55763b7dc984f", null ],
      [ "mcspiDmaIndex", "structMCSPI__OpenParams.html#a2ac3a45a175414a578667947ef548d18", null ]
    ] ],
    [ "MCSPI_ChConfig", "structMCSPI__ChConfig.html", [
      [ "chNum", "structMCSPI__ChConfig.html#ab17c0ddea55b65e89f6def7ad26ae7b3", null ],
      [ "frameFormat", "structMCSPI__ChConfig.html#a4a6549cd630c209437341c9c518e02aa", null ],
      [ "bitRate", "structMCSPI__ChConfig.html#a5617086b54dd1ff46d0baae70e988ee2", null ],
      [ "csPolarity", "structMCSPI__ChConfig.html#a9a1c821ed3d994ecaa7a100a8a77d0a7", null ],
      [ "trMode", "structMCSPI__ChConfig.html#aec0187e3421b884a664da6dce0643a4c", null ],
      [ "inputSelect", "structMCSPI__ChConfig.html#aa718f9e4da46a6d0ca91f1280ae3ce84", null ],
      [ "dpe0", "structMCSPI__ChConfig.html#a2428feb2d85e3aa8cc4d4652470a0aef", null ],
      [ "dpe1", "structMCSPI__ChConfig.html#aff72801ef373dac6252ac7952727575d", null ],
      [ "slvCsSelect", "structMCSPI__ChConfig.html#a1328026003816caff44f4c89872c2455", null ],
      [ "startBitEnable", "structMCSPI__ChConfig.html#aefab489bda73e883c24f91d6dc90af2e", null ],
      [ "startBitPolarity", "structMCSPI__ChConfig.html#af02b8b20975f1cd0cd09125e14c8fe66", null ],
      [ "csIdleTime", "structMCSPI__ChConfig.html#ad50cb93aa741ab74047561d2e54cd4a3", null ],
      [ "defaultTxData", "structMCSPI__ChConfig.html#a719acb3bbed9cc559f278257d3866761", null ],
      [ "txFifoTrigLvl", "structMCSPI__ChConfig.html#ae4b12cf34450847f72212fc5f812d9d3", null ],
      [ "rxFifoTrigLvl", "structMCSPI__ChConfig.html#a4125623379be93f37deb729dd5b333c7", null ]
    ] ],
    [ "MCSPI_Attrs", "structMCSPI__Attrs.html", [
      [ "baseAddr", "structMCSPI__Attrs.html#a75b1b1fa879c5f9e12d08da2cdc3c56d", null ],
      [ "inputClkFreq", "structMCSPI__Attrs.html#ad75f91618067bdb27aa9fddc6aec9f01", null ],
      [ "intrNum", "structMCSPI__Attrs.html#ae1472fd5de815ffaab70adb63473ed38", null ],
      [ "operMode", "structMCSPI__Attrs.html#a5230647329726edc89012fe9596c7162", null ],
      [ "intrPriority", "structMCSPI__Attrs.html#a359bf587e16e6aae894a3250ac20236c", null ],
      [ "chMode", "structMCSPI__Attrs.html#a4fb115e0add03fe92c8d615e7eae10f6", null ],
      [ "pinMode", "structMCSPI__Attrs.html#a1978d81ffd672b7414de333bb748ef54", null ],
      [ "initDelay", "structMCSPI__Attrs.html#a448f86e070dacb873eba3366c40e126b", null ]
    ] ],
    [ "MCSPI_ChObject", "structMCSPI__ChObject.html", [
      [ "chCfg", "structMCSPI__ChObject.html#af2c0907618794ad0e2e0d2095b6b0207", null ],
      [ "isOpen", "structMCSPI__ChObject.html#a1fbbd357b0ac3bbf4899cbeb2b5b3eb3", null ],
      [ "csDisable", "structMCSPI__ChObject.html#aaac7d77c9f3d64f580bf5100b5d8bb8f", null ],
      [ "csEnable", "structMCSPI__ChObject.html#a15701b38c07008e4f82101d62938fa67", null ],
      [ "curTxBufPtr", "structMCSPI__ChObject.html#ad833ebc6fb8da60518282f554eeb74e3", null ],
      [ "curRxBufPtr", "structMCSPI__ChObject.html#a3a09b7609fe12e9451fe3e4b9520c519", null ],
      [ "curTxWords", "structMCSPI__ChObject.html#aacd855742351960e01a600e4a154e86a", null ],
      [ "curRxWords", "structMCSPI__ChObject.html#a7461a33673726d45b3eec2477d1a7f6a", null ],
      [ "bufWidthShift", "structMCSPI__ChObject.html#ad70b6ace4b82262aebc6ef23ac443079", null ],
      [ "dataWidthBitMask", "structMCSPI__ChObject.html#a03d8e5b930f1a9ca3cb9ce27c79d20fd", null ],
      [ "effTxFifoDepth", "structMCSPI__ChObject.html#a5d183ba286fe0c4f62da6bc52c4caa54", null ],
      [ "effRxFifoDepth", "structMCSPI__ChObject.html#aa9b72de047a8402805da245d0f493751", null ],
      [ "intrMask", "structMCSPI__ChObject.html#af8287dadf750691a12086d7e9054246a", null ],
      [ "dmaChCfg", "structMCSPI__ChObject.html#aa0e573d2c56b10de0063131d844933f9", null ],
      [ "chConfRegVal", "structMCSPI__ChObject.html#a91cc119965f96863de731956dc3110b7", null ],
      [ "chCtrlRegVal", "structMCSPI__ChObject.html#a62f745efef801652f71aa324ec259f59", null ],
      [ "systRegVal", "structMCSPI__ChObject.html#a3a280a96786c7111a28c5de9080273e1", null ]
    ] ],
    [ "MCSPI_Object", "structMCSPI__Object.html", [
      [ "handle", "structMCSPI__Object.html#a659c231d4718d09fa52824f5c608a1b4", null ],
      [ "openPrms", "structMCSPI__Object.html#a064cb9938bb0c93bc8cb84a509106140", null ],
      [ "baseAddr", "structMCSPI__Object.html#acadca04921a6f181499384fc8a5bddfd", null ],
      [ "chObj", "structMCSPI__Object.html#ac7da2dfd190c5dc49503556576dadab5", null ],
      [ "isOpen", "structMCSPI__Object.html#aa3e4c28312f82cb374ecc3f483f036fa", null ],
      [ "transferSem", "structMCSPI__Object.html#a769f011c0ac0d5bb8912c294a858c437", null ],
      [ "transferSemObj", "structMCSPI__Object.html#ad4c4c9072cfe2f98fb7cd5bddfe360eb", null ],
      [ "hwiHandle", "structMCSPI__Object.html#a7254f20c765f5ca0e1aaf301e5a96441", null ],
      [ "hwiObj", "structMCSPI__Object.html#ae39700175f11c0bbec9c3a0772d4f0f1", null ],
      [ "currTransaction", "structMCSPI__Object.html#a6d466dce1caa3a3b736fa7d8a639ecac", null ],
      [ "mcspiDmaHandle", "structMCSPI__Object.html#aca68ad9de1a0d77c7be021092674c33c", null ]
    ] ],
    [ "MCSPI_Config", "structMCSPI__Config.html", [
      [ "attrs", "structMCSPI__Config.html#a9855facd83ddb5bd31a11a08ec33a0b5", null ],
      [ "object", "structMCSPI__Config.html#a478cd61311b2ad7a75e83153901891fc", null ]
    ] ],
    [ "MCSPI_CHANNEL_0", "group__DRV__MCSPI__MODULE.html#gab8d5c4edc0f02d25a1b3c23bb231b412", null ],
    [ "MCSPI_CHANNEL_1", "group__DRV__MCSPI__MODULE.html#ga3f52f1cda834a92e65271acf7156d67d", null ],
    [ "MCSPI_CHANNEL_2", "group__DRV__MCSPI__MODULE.html#gab5f4e5c4a64dd77b05ecb2634d7e7758", null ],
    [ "MCSPI_CHANNEL_3", "group__DRV__MCSPI__MODULE.html#ga471023734e5329ebc65a53092d70730e", null ],
    [ "MCSPI_OPER_MODE_POLLED", "group__DRV__MCSPI__MODULE.html#gac75aa9dcc8fe3251cb3326507b5ae3b1", null ],
    [ "MCSPI_OPER_MODE_INTERRUPT", "group__DRV__MCSPI__MODULE.html#ga6794018a599afa7637bc113c44b91ee0", null ],
    [ "MCSPI_OPER_MODE_DMA", "group__DRV__MCSPI__MODULE.html#gab8ae9bda705fca969feae66d33f4962f", null ],
    [ "MCSPI_MAX_NUM_CHANNELS", "group__DRV__MCSPI__MODULE.html#ga74887f9a92ea908748e13bb18c155f94", null ],
    [ "MCSPI_TRANSFER_COMPLETED", "group__DRV__MCSPI__MODULE.html#gaeb7c93069850e87483265149069539d1", null ],
    [ "MCSPI_TRANSFER_STARTED", "group__DRV__MCSPI__MODULE.html#ga454f40200e04c92eedcbae380a6f71f5", null ],
    [ "MCSPI_TRANSFER_CANCELLED", "group__DRV__MCSPI__MODULE.html#gaefb53aedcfd67cf0c23195206fb8e87a", null ],
    [ "MCSPI_TRANSFER_FAILED", "group__DRV__MCSPI__MODULE.html#ga646ae244aa2508c975199fb30b8bd211", null ],
    [ "MCSPI_TRANSFER_CSN_DEASSERT", "group__DRV__MCSPI__MODULE.html#ga6acd9f7a8baa6f88ec8f9df41d4ac0ba", null ],
    [ "MCSPI_TRANSFER_TIMEOUT", "group__DRV__MCSPI__MODULE.html#ga83bf183e3c28c7641caf951431f89625", null ],
    [ "MCSPI_TRANSFER_MODE_BLOCKING", "group__DRV__MCSPI__MODULE.html#gab50fd130c0f0d29545a83be89f230b8e", null ],
    [ "MCSPI_TRANSFER_MODE_CALLBACK", "group__DRV__MCSPI__MODULE.html#gab2e9e948624aa8ff39cc5a75e00adb6f", null ],
    [ "MCSPI_MS_MODE_CONTROLLER", "group__DRV__MCSPI__MODULE.html#ga69f7a16bf39d0ed47de1970b599a7f0c", null ],
    [ "MCSPI_MS_MODE_PERIPHERAL", "group__DRV__MCSPI__MODULE.html#ga1447ffe86b17d95258dcad6594a3f0a9", null ],
    [ "MCSPI_FF_POL0_PHA0", "group__DRV__MCSPI__MODULE.html#ga439e8f03edc99644be40a5dfbb1b27a9", null ],
    [ "MCSPI_FF_POL0_PHA1", "group__DRV__MCSPI__MODULE.html#ga8ee6f5b71917cfb8fdc05cd48620c2e4", null ],
    [ "MCSPI_FF_POL1_PHA0", "group__DRV__MCSPI__MODULE.html#gac5f58da23b56c34be6d94abf7f00e97a", null ],
    [ "MCSPI_FF_POL1_PHA1", "group__DRV__MCSPI__MODULE.html#gadfb2cdd1fdcc91bca2bab7f9449c8278", null ],
    [ "MCSPI_CS_POL_HIGH", "group__DRV__MCSPI__MODULE.html#gac00e3b7be4c4918a7acf16c07577aac8", null ],
    [ "MCSPI_CS_POL_LOW", "group__DRV__MCSPI__MODULE.html#ga07e7c1194b73b2f1ed20562bb3aedd44", null ],
    [ "MCSPI_TR_MODE_TX_RX", "group__DRV__MCSPI__MODULE.html#ga5f4e62b9a5145858280b8a6b78d65dad", null ],
    [ "MCSPI_TR_MODE_RX_ONLY", "group__DRV__MCSPI__MODULE.html#ga079065c1e5dbe530f764692e076881d9", null ],
    [ "MCSPI_TR_MODE_TX_ONLY", "group__DRV__MCSPI__MODULE.html#ga8ab60e51e1dadfe520dec5115c2f5d1a", null ],
    [ "MCSPI_IS_D0", "group__DRV__MCSPI__MODULE.html#ga3398429686392c9c2d0dfe06f7dcc7d4", null ],
    [ "MCSPI_IS_D1", "group__DRV__MCSPI__MODULE.html#ga3d4bd7677126fc532635faa9a5a841ca", null ],
    [ "MCSPI_DPE_ENABLE", "group__DRV__MCSPI__MODULE.html#ga9434813587ba1a7dcfb9a0a8b66623f9", null ],
    [ "MCSPI_DPE_DISABLE", "group__DRV__MCSPI__MODULE.html#gacfcc8d94ee2e10720840eaad837ce57f", null ],
    [ "MCSPI_SLV_CS_SELECT_0", "group__DRV__MCSPI__MODULE.html#ga6e279a2b49068f39ccaaf440fd2c67c9", null ],
    [ "MCSPI_SLV_CS_SELECT_1", "group__DRV__MCSPI__MODULE.html#ga8f5eb88f42ddea3d0482306ef11bf2b5", null ],
    [ "MCSPI_SLV_CS_SELECT_2", "group__DRV__MCSPI__MODULE.html#ga5a3d284fb16accadcc5bf4ff0be3afc7", null ],
    [ "MCSPI_SLV_CS_SELECT_3", "group__DRV__MCSPI__MODULE.html#ga399cd4ef12d0400125d2615eabd6b561", null ],
    [ "MCSPI_SB_POL_HIGH", "group__DRV__MCSPI__MODULE.html#gad2e813f62e94e18e01f78a9b411bb807", null ],
    [ "MCSPI_SB_POL_LOW", "group__DRV__MCSPI__MODULE.html#gaf5587a0984eb5f9c29d6b7e499a7cc4d", null ],
    [ "MCSPI_TCS0_0_CLK", "group__DRV__MCSPI__MODULE.html#ga47d5d6f22de36bf91e167f83fa1b6a0f", null ],
    [ "MCSPI_TCS0_1_CLK", "group__DRV__MCSPI__MODULE.html#gac58ac95f977011e5b9cbb3edeec28740", null ],
    [ "MCSPI_TCS0_2_CLK", "group__DRV__MCSPI__MODULE.html#ga8e6a2cfe47ec2daa916af02cae229ab3", null ],
    [ "MCSPI_TCS0_3_CLK", "group__DRV__MCSPI__MODULE.html#gac1d453aab852bc1c27bf6183a8914e59", null ],
    [ "MCSPI_CH_MODE_SINGLE", "group__DRV__MCSPI__MODULE.html#gaa3663721672a8673989b7104ea826713", null ],
    [ "MCSPI_CH_MODE_MULTI", "group__DRV__MCSPI__MODULE.html#ga42cb25b77155f07fe058c6d81d1a1e32", null ],
    [ "MCSPI_PINMODE_3PIN", "group__DRV__MCSPI__MODULE.html#ga1b8f03a6e51528ead614029fe659de07", null ],
    [ "MCSPI_PINMODE_4PIN", "group__DRV__MCSPI__MODULE.html#gaa0e6d15b21841fcb2970e16a9843d87a", null ],
    [ "MCSPI_INITDLY_0", "group__DRV__MCSPI__MODULE.html#gae4e12baa9f6ce8efd495cde1ca34d803", null ],
    [ "MCSPI_INITDLY_4", "group__DRV__MCSPI__MODULE.html#ga1d82310c73b406ad1117ed7ab3950167", null ],
    [ "MCSPI_INITDLY_8", "group__DRV__MCSPI__MODULE.html#ga7d1fbe4e33059cd72c6ec199abe11316", null ],
    [ "MCSPI_INITDLY_16", "group__DRV__MCSPI__MODULE.html#gabcdb83a136b23476b0ed63389abd91a3", null ],
    [ "MCSPI_INITDLY_32", "group__DRV__MCSPI__MODULE.html#ga467ce5fb0a6586d7da5dcb3e099e2f12", null ],
    [ "MCSPI_FIFO_LENGTH", "group__DRV__MCSPI__MODULE.html#gae812776af88501f9fa31987c55ecba54", null ],
    [ "MCSPI_RX_FIFO_ENABLE", "group__DRV__MCSPI__MODULE.html#ga0af60b6c01810f584d28b33d3475452d", null ],
    [ "MCSPI_RX_FIFO_DISABLE", "group__DRV__MCSPI__MODULE.html#gac41bb9a19845e7c2770b7348e1394617", null ],
    [ "MCSPI_TX_FIFO_ENABLE", "group__DRV__MCSPI__MODULE.html#ga07427836253c988763d4ba6dc7ceb26a", null ],
    [ "MCSPI_TX_FIFO_DISABLE", "group__DRV__MCSPI__MODULE.html#ga30725ee81f017468b53263e635684484", null ],
    [ "MCSPI_REG_OFFSET", "group__DRV__MCSPI__MODULE.html#gab495c02282f26f698cac3f280dfc7da3", null ],
    [ "MCSPI_CHCONF", "group__DRV__MCSPI__MODULE.html#ga3c2e983f3d98da3ecb3e342ee737ef1c", null ],
    [ "MCSPI_CHSTAT", "group__DRV__MCSPI__MODULE.html#gaa30204efe0c0512c7ab51e7efc1b0e1d", null ],
    [ "MCSPI_CHCTRL", "group__DRV__MCSPI__MODULE.html#ga97cf1b26053f89e1d2db63dc8f96d2d2", null ],
    [ "MCSPI_CHTX", "group__DRV__MCSPI__MODULE.html#gabc11d5f12cff17e21e70dbe700dbedb0", null ],
    [ "MCSPI_CHRX", "group__DRV__MCSPI__MODULE.html#gac66a030c8b38f05d21df4ee7c806e2c1", null ],
    [ "MCSPI_CLKD_MASK", "group__DRV__MCSPI__MODULE.html#ga7b39c11444c20b39afc53299c32df1dd", null ],
    [ "MCSPI_IRQSTATUS_CLEAR_ALL", "group__DRV__MCSPI__MODULE.html#gae6f831c9e209104049d95efde0fe95e1", null ],
    [ "MCSPI_Handle", "group__DRV__MCSPI__MODULE.html#ga859dbc47eb349c2d5df779923c1d5ac9", null ],
    [ "MCSPI_CallbackFxn", "group__DRV__MCSPI__MODULE.html#gaae5efefe555d07856ddea7034d5a40f4", null ],
    [ "MCSPI_init", "group__DRV__MCSPI__MODULE.html#ga7ab49f55fcfb89a487857e9a27ca7083", null ],
    [ "MCSPI_deinit", "group__DRV__MCSPI__MODULE.html#gaf34ea4d022337821d4c7066505726893", null ],
    [ "MCSPI_open", "group__DRV__MCSPI__MODULE.html#gabedb148b6832d0c132352b9c4fd0a923", null ],
    [ "MCSPI_close", "group__DRV__MCSPI__MODULE.html#ga12824149d7be9c07abd4cb120ec7cf13", null ],
    [ "MCSPI_chConfig", "group__DRV__MCSPI__MODULE.html#gaf55bfd5fe8741647f107cacba32a04e3", null ],
    [ "MCSPI_dmaChConfig", "group__DRV__MCSPI__MODULE.html#ga07c78f625ea6e766b3459bd350f35c9b", null ],
    [ "MCSPI_transfer", "group__DRV__MCSPI__MODULE.html#ga35061166ed36e50dc6d7b38a8fbf13e9", null ],
    [ "MCSPI_transferCancel", "group__DRV__MCSPI__MODULE.html#ga682d7e8ba62f079a7a463355e23d133b", null ],
    [ "MCSPI_OpenParams_init", "group__DRV__MCSPI__MODULE.html#ga8e2f6ba4de2ec70859f37324e6aa65ba", null ],
    [ "MCSPI_ChConfig_init", "group__DRV__MCSPI__MODULE.html#gab3158f44e2826e25f90111aa24453cc1", null ],
    [ "MCSPI_Transaction_init", "group__DRV__MCSPI__MODULE.html#ga427c74cdbf56cf1081b167728beb4a7f", null ],
    [ "MCSPI_getBaseAddr", "group__DRV__MCSPI__MODULE.html#gac52df4ca2575f0139fc603d069799073", null ],
    [ "MCSPI_reConfigFifo", "group__DRV__MCSPI__MODULE.html#ga3ee437e7c56248b80869d51d441fe4cd", null ],
    [ "MCSPI_getBufWidthShift", "group__DRV__MCSPI__MODULE.html#gaf4a0b1f771d19e25a1e91deb5c2d2e43", null ],
    [ "MCSPI_readChStatusReg", "group__DRV__MCSPI__MODULE.html#ga1f7d6df57b9b4131da279698202b612a", null ],
    [ "MCSPI_readChCtrlReg", "group__DRV__MCSPI__MODULE.html#ga25ffd0409bab65b9abc25c0bf5de5d73", null ],
    [ "MCSPI_writeChCtrlReg", "group__DRV__MCSPI__MODULE.html#ga15e08ffa29ce4f9f979e78bdb2e7134e", null ],
    [ "MCSPI_readChConf", "group__DRV__MCSPI__MODULE.html#gae165f6f3c74c25c261de09a58a4207db", null ],
    [ "MCSPI_writeChConfReg", "group__DRV__MCSPI__MODULE.html#ga2a4c303d8853cca2d2bdf6d85f3b7c2a", null ],
    [ "MCSPI_writeTxDataReg", "group__DRV__MCSPI__MODULE.html#gacf3205cd1f49c52848ea7f3b7bc7cb3d", null ],
    [ "MCSPI_enableTxFIFO", "group__DRV__MCSPI__MODULE.html#ga0d079469a9c669bee03475ec4046f664", null ],
    [ "MCSPI_enableRxFIFO", "group__DRV__MCSPI__MODULE.html#gaf32b5fcdd91da95f0fcf7020429112e0", null ],
    [ "MCSPI_readRxDataReg", "group__DRV__MCSPI__MODULE.html#ga532219eca14e3d2d768d76df7db46d94", null ],
    [ "MCSPI_setDataWidth", "group__DRV__MCSPI__MODULE.html#gaf75d0e2f733ec56a95a1ec98984e1046", null ],
    [ "gMcspiConfig", "group__DRV__MCSPI__MODULE.html#ga0fd285a89004e0eacc5a6be6c7136ea7", null ],
    [ "gMcspiConfigNum", "group__DRV__MCSPI__MODULE.html#ga09891815abcd4e3d8b5fc36e4d9c9adb", null ]
];

==> mcu_plus_sdk_am263x_11_01_00_19_docs_only.tar.xz: mcu_plus_sdk_am263x_11_01_00_19_docs_only/docs/api_guide_am263x/group__DRV__MCSPI__MODULE.js <==
var group__DRV__MCSPI__MODULE =
[
    [ "mcspi/v0/mcspi.h", "mcspi_2v0_2mcspi_8h.html", null ],
    [ "MCSPI_OpenParams", "structMCSPI__OpenParams.html", [
      [ "transferMode", "structMCSPI__OpenParams.html#a0b4ecaba7263bd18bc7e40924d8d6c97", null ],
      [ "transferTimeout", "structMCSPI__OpenParams.html#a1a61eb9a3dafb53eb367e31b41a7116b", null ],
      [ "transferCallbackFxn", "structMCSPI__OpenParams.html#a43a61b1bdcb52eebaf0d756f5e5500d8", null ],
      [ "msMode", "structMCSPI__OpenParams.html#ad539f2b8771de73167b55763b7dc984f", null ],
      [ "mcspiDmaIndex", "structMCSPI__OpenParams.html#a2ac3a45a175414a578667947ef548d18", null ]
    ] ],
    [ "MCSPI_Attrs", "structMCSPI__Attrs.html", [
      [ "baseAddr", "structMCSPI__Attrs.html#a75b1b1fa879c5f9e12d08da2cdc3c56d", null ],
      [ "inputClkFreq", "structMCSPI__Attrs.html#ad75f91618067bdb27aa9fddc6aec9f01", null ],
      [ "intrNum", "structMCSPI__Attrs.html#ae1472fd5de815ffaab70adb63473ed38", null ],
      [ "operMode", "structMCSPI__Attrs.html#a5230647329726edc89012fe9596c7162", null ],
      [ "intrPriority", "structMCSPI__Attrs.html#a359bf587e16e6aae894a3250ac20236c", null ],
      [ "chMode", "structMCSPI__Attrs.html#a4fb115e0add03fe92c8d615e7eae10f6", null ],
      [ "pinMode", "structMCSPI__Attrs.html#a1978d81ffd672b7414de333bb748ef54", null ],
      [ "initDelay", "structMCSPI__Attrs.html#a448f86e070dacb873eba3366c40e126b", null ],
      [ "multiWordAccess", "structMCSPI__Attrs.html#aed88676acb57223688f5bcf72cf6fd4a", null ]
    ] ],
    [ "MCSPI_Object", "structMCSPI__Object.html", [
      [ "handle", "structMCSPI__Object.html#a659c231d4718d09fa52824f5c608a1b4", null ],
      [ "openPrms", "structMCSPI__Object.html#a064cb9938bb0c93bc8cb84a509106140", null ],
      [ "baseAddr", "structMCSPI__Object.html#acadca04921a6f181499384fc8a5bddfd", null ],
      [ "chObj", "structMCSPI__Object.html#ac7da2dfd190c5dc49503556576dadab5", null ],
      [ "isOpen", "structMCSPI__Object.html#aa3e4c28312f82cb374ecc3f483f036fa", null ],
      [ "transferSem", "structMCSPI__Object.html#a769f011c0ac0d5bb8912c294a858c437", null ],
      [ "transferSemObj", "structMCSPI__Object.html#ad4c4c9072cfe2f98fb7cd5bddfe360eb", null ],
      [ "hwiHandle", "structMCSPI__Object.html#a7254f20c765f5ca0e1aaf301e5a96441", null ],
      [ "hwiObj", "structMCSPI__Object.html#ae39700175f11c0bbec9c3a0772d4f0f1", null ],
      [ "transaction", "structMCSPI__Object.html#a358d85e4cf82aea7204131610f830a8b", null ],
      [ "mcspiDmaHandle", "structMCSPI__Object.html#aca68ad9de1a0d77c7be021092674c33c", null ],
      [ "mcspiLldObject", "structMCSPI__Object.html#a0b51d3fbe7e9ce2b76007e6ebff177d3", null ],
      [ "mcspiLldHandle", "structMCSPI__Object.html#abe573a87994ff7083a0e78bf5e6b4986", null ],
      [ "mcspiLldInitObj", "structMCSPI__Object.html#aec7ad9f6ff0ef1a083ae6f338ffee66f", null ]
    ] ],
    [ "MCSPI_Config", "structMCSPI__Config.html", [
      [ "attrs", "structMCSPI__Config.html#a9855facd83ddb5bd31a11a08ec33a0b5", null ],
      [ "object", "structMCSPI__Config.html#a478cd61311b2ad7a75e83153901891fc", null ]
    ] ],
    [ "MCSPI_TRANSFER_MODE_BLOCKING", "group__DRV__MCSPI__MODULE.html#gab50fd130c0f0d29545a83be89f230b8e", null ],
    [ "MCSPI_TRANSFER_MODE_CALLBACK", "group__DRV__MCSPI__MODULE.html#gab2e9e948624aa8ff39cc5a75e00adb6f", null ],
    [ "MCSPI_Handle", "group__DRV__MCSPI__MODULE.html#gae5c48c3d1206a823e48b3180eeb9bca1", null ],
    [ "MCSPI_CallbackFxn", "group__DRV__MCSPI__MODULE.html#gaae5efefe555d07856ddea7034d5a40f4", null ],
    [ "MCSPI_init", "group__DRV__MCSPI__MODULE.html#ga7ab49f55fcfb89a487857e9a27ca7083", null ],
    [ "MCSPI_deinit", "group__DRV__MCSPI__MODULE.html#gaf34ea4d022337821d4c7066505726893", null ],
    [ "MCSPI_open", "group__DRV__MCSPI__MODULE.html#gabedb148b6832d0c132352b9c4fd0a923", null ],
    [ "MCSPI_close", "group__DRV__MCSPI__MODULE.html#ga12824149d7be9c07abd4cb120ec7cf13", null ],
    [ "MCSPI_getHandle", "group__DRV__MCSPI__MODULE.html#ga5c4aa6571c035b07058b12bb3520c980", null ],
    [ "MCSPI_chConfig", "group__DRV__MCSPI__MODULE.html#gaf55bfd5fe8741647f107cacba32a04e3", null ],
    [ "MCSPI_dmaChConfig", "group__DRV__MCSPI__MODULE.html#ga07c78f625ea6e766b3459bd350f35c9b", null ],
    [ "MCSPI_transfer", "group__DRV__MCSPI__MODULE.html#ga35061166ed36e50dc6d7b38a8fbf13e9", null ],
    [ "MCSPI_transferCancel", "group__DRV__MCSPI__MODULE.html#ga682d7e8ba62f079a7a463355e23d133b", null ],
    [ "MCSPI_OpenParams_init", "group__DRV__MCSPI__MODULE.html#ga8e2f6ba4de2ec70859f37324e6aa65ba", null ],
    [ "MCSPI_ChConfig_init", "group__DRV__MCSPI__MODULE.html#gab3158f44e2826e25f90111aa24453cc1", null ],
    [ "MCSPI_Transaction_init", "group__DRV__MCSPI__MODULE.html#ga427c74cdbf56cf1081b167728beb4a7f", null ],
    [ "MCSPI_reConfigFifo", "group__DRV__MCSPI__MODULE.html#ga3ee437e7c56248b80869d51d441fe4cd", null ],
    [ "MCSPI_getBaseAddr", "group__DRV__MCSPI__MODULE.html#gac52df4ca2575f0139fc603d069799073", null ],
    [ "gMcspiConfig", "group__DRV__MCSPI__MODULE.html#ga0fd285a89004e0eacc5a6be6c7136ea7", null ],
    [ "gMcspiConfigNum", "group__DRV__MCSPI__MODULE.html#ga09891815abcd4e3d8b5fc36e4d9c9adb", null ]
];
